Module blaxel.core.client.models.custom_domain
==============================================

Classes
-------

`CustomDomain(metadata: blaxel.core.client.types.Unset | ForwardRef('CustomDomainMetadata') = <blaxel.core.client.types.Unset object>, spec: blaxel.core.client.types.Unset | ForwardRef('CustomDomainSpec') = <blaxel.core.client.types.Unset object>)`
:   Custom domain for preview deployments
    The custom domain represents a base domain (e.g., example.com) that will be used
    to serve preview deployments. Each preview will be accessible at a subdomain:
    <preview-id>.preview.<base-domain> (e.g., abc123.preview.example.com)
    
        Attributes:
            metadata (Union[Unset, CustomDomainMetadata]): Custom domain metadata
            spec (Union[Unset, CustomDomainSpec]): Custom domain specification
    
    Method generated by attrs for class CustomDomain.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `metadata`
    :

    `spec`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :